pro ssw_read_rstn, rstnfiles, index, aband_data, bband_data , $
     afrequency=afrequency, bfrequency=bfrequency, refresh=refresh


;+
;   Name: ssw_read_rstn
;
;   Purpose: read ngdc 'srs' format RSTN data
;
;
;   Input Parameters:
;      rstnfiles - file or files to read ; NOTE - only scalar for today
;
;   Output Parameters:
;      index - header vector including SSW/utplot ready times
;      aband_data / bband_data - scan data (nrecs,401)
;
;   Keyword Parameters:
;      afrequency - vector of 401 elements = aband frequency sample MHz
;      bfrequency - same for b channel                              MHz
common ssw_read_rstn_blk, indstruct


recsize=826
nfreqs =401
for i=0,n_elements(rstnfiles)-1 do begin 
   openr,lun,rstnfiles(i),/get_lun
   stat=fstat(lun)
   delvarx,data
   data=bytarr(stat.size)
   nrecs=stat.size/recsize
   readu,lun,data
   free_lun,lun
   data=reform(data,recsize,nrecs,/over)
   extime=anytim(replicate(0L,nrecs),/ex)
   tmap=[3,4,5,2,1,0]
   mmap=[0,1,2,4,5,6]
   for tt=0,5 do extime(mmap(tt),*)=reform(data(tmap(tt),*))
   utcs=anytim(extime,/utc_int)
   aband_data=transpose(data(24:424,*))
   bband_data=transpose(data(425:825,*))
endfor

afrequency=25.+(findgen(nfreqs)*50) /(nfreqs-1)
bfrequency=75.+(findgen(nfreqs)*105)/(nfreqs-1)

if n_elements(indstruct) eq 0 or keyword_set(refresh) then begin  
   indstruct={time:0l,mjd:0l,                                 $
           aband_lo:min(afrequency),aband_hi:max(afrequency), $
           bband_lo:min(bfrequency),bband_hi:max(bfrequency), $
           number_waves:nfreqs}
endif

index=replicate(indstruct,nrecs)    ; define return indices
index.mjd=utcs.mjd
index.time=utcs.time

return
end
